==> monaco-vscode-debug-service-override-11.1.2.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugLifecycle.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { localize } from 'vscode/vscode/vs/nls';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';
import { IDialogService } from 'vscode/vscode/vs/platform/dialogs/common/dialogs.service';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug.service';
import { ILifecycleService } from 'vscode/vscode/vs/workbench/services/lifecycle/common/lifecycle.service';

let DebugLifecycle = class DebugLifecycle {
    constructor(lifecycleService, debugService, configurationService, dialogService) {
        this.debugService = debugService;
        this.configurationService = configurationService;
        this.dialogService = dialogService;
        this.disposable = lifecycleService.onBeforeShutdown(async (e) => e.veto(this.shouldVetoShutdown(e.reason), 'veto.debug'));
    }
    shouldVetoShutdown(_reason) {
        const rootSessions = this.debugService.getModel().getSessions().filter(s => s.parentSession === undefined);
        if (rootSessions.length === 0) {
            return false;
        }
        const shouldConfirmOnExit = this.configurationService.getValue('debug').confirmOnExit;
        if (shouldConfirmOnExit === 'never') {
            return false;
        }
        return this.showWindowCloseConfirmation(rootSessions.length);
    }
    dispose() {
        return this.disposable.dispose();
    }
    async showWindowCloseConfirmation(numSessions) {
        let message;
        if (numSessions === 1) {
            message = ( localize(
                6123,
                "There is an active debug session, are you sure you want to stop it?"
            ));
        }
        else {
            message = ( localize(
                6124,
                "There are active debug sessions, are you sure you want to stop them?"
            ));
        }
        const res = await this.dialogService.confirm({
            message,
            type: 'warning',
            primaryButton: ( localize(6125, "&&Stop Debugging"))
        });
        return !res.confirmed;
    }
};
DebugLifecycle = ( (__decorate([
    ( (__param(0, ILifecycleService))),
    ( (__param(1, IDebugService))),
    ( (__param(2, IConfigurationService))),
    ( (__param(3, IDialogService)))
], DebugLifecycle)));

export { DebugLifecycle };

==> monaco-vscode-debug-service-override-12.0.0.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugLifecycle.js <==

import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { localize } from 'vscode/vscode/vs/nls';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';
import { IDialogService } from 'vscode/vscode/vs/platform/dialogs/common/dialogs.service';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug.service';
import { ILifecycleService } from 'vscode/vscode/vs/workbench/services/lifecycle/common/lifecycle.service';

let DebugLifecycle = class DebugLifecycle {
    constructor(lifecycleService, debugService, configurationService, dialogService) {
        this.debugService = debugService;
        this.configurationService = configurationService;
        this.dialogService = dialogService;
        this.disposable = lifecycleService.onBeforeShutdown(async (e) => e.veto(this.shouldVetoShutdown(e.reason), 'veto.debug'));
    }
    shouldVetoShutdown(_reason) {
        const rootSessions = this.debugService.getModel().getSessions().filter(s => s.parentSession === undefined);
        if (rootSessions.length === 0) {
            return false;
        }
        const shouldConfirmOnExit = this.configurationService.getValue('debug').confirmOnExit;
        if (shouldConfirmOnExit === 'never') {
            return false;
        }
        return this.showWindowCloseConfirmation(rootSessions.length);
    }
    dispose() {
        return this.disposable.dispose();
    }
    async showWindowCloseConfirmation(numSessions) {
        let message;
        if (numSessions === 1) {
            message = ( localize(
                5570,
                "There is an active debug session, are you sure you want to stop it?"
            ));
        }
        else {
            message = ( localize(
                5571,
                "There are active debug sessions, are you sure you want to stop them?"
            ));
        }
        const res = await this.dialogService.confirm({
            message,
            type: 'warning',
            primaryButton: ( localize(5572, "&&Stop Debugging"))
        });
        return !res.confirmed;
    }
};
DebugLifecycle = ( __decorate([
    ( __param(0, ILifecycleService)),
    ( __param(1, IDebugService)),
    ( __param(2, IConfigurationService)),
    ( __param(3, IDialogService))
], DebugLifecycle));

export { DebugLifecycle };
